# Provisioning SAP LeanIX from SAP for Me (NGCS)
### On this page
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/provisioning-sap-leanix-workspace#prerequisites)
  * [Context](https://help.sap.com/docs/leanix/ea/provisioning-sap-leanix-workspace#context)
  * [Procedure](https://help.sap.com/docs/leanix/ea/provisioning-sap-leanix-workspace#procedure)


Learn how to provision workspaces in SAP LeanIX using SAP for Me.
